@@ -25,11 +25,7 @@ class srcb:
          data = {"files": [{"content": cont, "languageId": 303}]}
          re = self.r.post(self.base_url, json = data, headers=head)
          dic = json.loads(re.text)
-         err = dic['message'] or "empty"
          key = dic['key']
          return f'https://sourceb.in/{key}'
       except:
-        if err != "empty":
-            return "An error has occured. Here is the message from the server: " + err
-        else:
-            return "An unknown error has occurred. Please contact the library developer."
\ No newline at end of file
+          return "An unknown error has occurred. Please contact the library developer."
\ No newline at end of file
